CandidateQuery class

Query for candidates.

Constructors

CandidateQuery({String? candidateType, CandidateStatus? status, double? minConfidence, bool? needsReview, int? limit, int? offset})
const

Properties

candidateType String?
Filter by type.
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
Limit results.
final
minConfidence double?
Filter by minimum confidence.
final
needsReview bool?
Include only candidates needing review.
final
offset int?
Offset for pagination.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status CandidateStatus?
Filter by status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited