CandidateStatus enum

Candidate status. Reference: Design Section 2.3 - open | qualifying | ready | confirmed | rejected | promoted | orphaned | merged

Inheritance
Available extensions

Values

open → const CandidateStatus

Initial state - awaiting fragments.

qualifying → const CandidateStatus

Evaluation in progress.

ready → const CandidateStatus

All required fragments attached, awaiting confirmation.

confirmed → const CandidateStatus

Accepted as valid entity source.

rejected → const CandidateStatus

Failed validation.

Entity created from this candidate.

orphaned → const CandidateStatus

Source evidence deleted (cascade).

merged → const CandidateStatus

Merged into another candidate.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) CandidateStatus

Constants

values → const List<CandidateStatus>
A constant List of the values in this enum, in order of their declaration.