ContextService class
Service for L2 ContextOps Layer operations.
Constructors
- ContextService({required ContextStoragePort storage, required EventStoragePort eventStorage, LlmPort? llm, ClaimVerificationPort? verifier})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildContext(
{required String query, required ContextPurpose purpose, int tokenBudget = 4096, SelectionStrategy strategy = SelectionStrategy.relevance}) → Future< ContextBundle> - Build context bundle for a query.
-
createSummary(
{required SummaryType summaryType, required String title, required List< String> eventIds, String? scope, String? parentId}) → Future<SummaryNode> - Create summary from events.
-
getChildSummaries(
String parentId) → Future< List< SummaryNode> > - Get child summaries.
-
getClaim(
String claimId) → Future< Claim?> - Get claim by ID.
-
getContextBundle(
String bundleId) → Future< ContextBundle?> - Get context bundle by ID.
-
getPendingClaims(
) → Future< List< Claim> > - Get pending claims.
-
getSummaryNode(
String nodeId) → Future< SummaryNode?> - Get summary node by ID.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshSummary(
String nodeId) → Future< SummaryNode> - Refresh stale summary.
-
toString(
) → String -
A string representation of this object.
inherited
-
verifyClaims(
{required String responseText, String? responseId, List< String> ? evidenceIds}) → Future<List< Claim> > - Extract and verify claims from text.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited