ExtractionMethod enum

Extraction methods.

Inheritance
Available extensions

Values

rule → const ExtractionMethod

Rule-based extraction.

regex → const ExtractionMethod

Regex pattern matching.

ocr → const ExtractionMethod

OCR (Optical Character Recognition).

parser → const ExtractionMethod

Parser-based extraction.

llm → const ExtractionMethod

LLM-based extraction.

manual → const ExtractionMethod

User-provided.

unknown → const ExtractionMethod

Unknown method.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) ExtractionMethod

Constants

values → const List<ExtractionMethod>
A constant List of the values in this enum, in order of their declaration.