LogEntry class

Log entry for a run.

Constructors

LogEntry({required DateTime timestamp, required String level, required String message})
const
LogEntry.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
level String
Log level: info, warn, error.
final
message String
Log message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
When the log entry was created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited