RunStatus enum

Status of a run.

Inheritance
Available extensions

Values

running → const RunStatus

Run is currently executing.

success → const RunStatus

Run completed successfully.

failed → const RunStatus

Run failed.

skipped → const RunStatus

Run was skipped (e.g., idempotency).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) RunStatus
Create from string.

Constants

values → const List<RunStatus>
A constant List of the values in this enum, in order of their declaration.