SkillTrigger class

Skill trigger configuration.

Constructors

SkillTrigger({required TriggerType type, String? patternId, List<String> eventTypes = const [], String? schedule, String? condition, int priority = 0})
const
SkillTrigger.fromJson(Map<String, dynamic> json)
factory

Properties

condition String?
Condition expression.
final
eventTypes List<String>
Event types to trigger on.
final
hashCode int
The hash code for this object.
no setterinherited
patternId String?
Pattern ID to match (for pattern triggers).
final
priority int
Priority (higher = more priority).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedule String?
Schedule expression (for scheduled triggers).
final
type TriggerType
Trigger type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited