IdempotencyKeyStrategy class abstract
Idempotency key generation strategies.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateContentBased(
String operation, String contentHash) → String - Generate a content-based key.
-
generateRequestBased(
String userId, String requestId) → String - Generate a request-based key.
-
generateTimeBased(
String jobId, DateTime timestamp) → String - Generate a time-based key.
Constants
- contentBased → const String
- Content-based key: {operation}:{hash}.
- requestBased → const String
- Request-based key: {user}:{request_id}.
- timeBased → const String
- Time-based key: {jobId}:{period}.