UnresolvedIssue class
An unresolved issue preventing candidate confirmation.
Constructors
- UnresolvedIssue({required String code, required IssueType type, String? field, required String description, String? suggestion})
-
const
-
UnresolvedIssue.fromJson(Map<
String, dynamic> json) -
factory
Properties
- code → String
-
Issue code.
final
- description → String
-
Issue description.
final
- field → String?
-
Affected field (if applicable).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestion → String?
-
Suggested resolution.
final
- type → IssueType
-
Issue type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited